@@ -19,6 +19,7 @@
 ######################################################
 
 import pint
+import logging
 
 import biosignalml.rdf             as rdf
 import biosignalml.rdf.sparqlstore as sparqlstore
@@ -113,6 +114,7 @@ class UnitStore(object):
   def get_unit(self, uri):
   #-----------------------
     uri = str(uri)
+    #logging.debug('Looking for %s', uri)
     unit = self._cache.get(uri)
     if unit is None:
       name = strip_prefix(uri)
